@@ -229,6 +229,12 @@ def create_targets(
     row_spacing=1,
     empty_desc="empty",
 ):
+
+    if layout_range != "A1:M9":
+        raise NotImplementedError(
+            f"Targets placement algorithm implemented only for the case of default position of layout on layout sheet: `{layout_range}`"
+        )
+
     try:
         targets_sheet = workbook.worksheet(target_sheet_name)
     except gspread.WorksheetNotFound as e:
